# jeeves-jira

[![Build Status](https://github.com/jeeves-sh/jeeves-jira/workflows/test/badge.svg?branch=master&event=push)](https://github.com/jeeves-sh/jeeves-jira/actions?query=workflow%3Atest)
[![codecov](https://codecov.io/gh/jeeves-sh/jeeves-jira/branch/master/graph/badge.svg)](https://codecov.io/gh/jeeves-sh/jeeves-jira)
[![Python Version](https://img.shields.io/pypi/pyversions/jeeves-jira.svg)](https://pypi.org/project/jeeves-jira/)
[![wemake-python-styleguide](https://img.shields.io/badge/style-wemake-000000.svg)](https://github.com/wemake-services/wemake-python-styleguide)

Yet another JIRA issue manager CLI with emphasis on task chains.


## Features

- Fully typed with annotations and checked with mypy, [PEP561 compatible](https://www.python.org/dev/peps/pep-0561/)
- Add yours!


## Installation

```bash
pip install jirajumper
```


## License

[MIT](https://github.com/jeeves-sh/jeeves-jira/blob/master/LICENSE)


## Credits

This project was generated with [`wemake-python-package`](https://github.com/wemake-services/wemake-python-package). Current template version is: [86ec1f15472f7c9f634cdbaa0d33eddf166888b2](https://github.com/wemake-services/wemake-python-package/tree/86ec1f15472f7c9f634cdbaa0d33eddf166888b2). See what is [updated](https://github.com/wemake-services/wemake-python-package/compare/86ec1f15472f7c9f634cdbaa0d33eddf166888b2...master) since then.
